==> util-0.0.2.9-sources.jar: com/crawler/utils/SmsClient.java <==
package com.crawler.utils;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;

import com.crawler.rest.exceptions.extendExceptions.RestSimpleException;

public class SmsClient {
	
	private static final String smsSvcUrl = "http://43.243.130.33:8860";	   //服务器URL 地址
	private static final String cust_code = "300270";									 //账号
	private static final String password = "6C7C6CP7ZM";		 								//密码
	private static final String sp_code = "10690651549951";                  //接入码（扩展码）
	
	/**
	 * 短信发送
	 * @param phone
	 * @param content
	 */
	public static void send(String phone, String content){
		try {
			SmsClient.sendSms(phone, content);
		} catch (IOException e) {
			throw new RestSimpleException("短信发送失败");
		}
	}

	public static void sendSms(String mobiles, String content) throws IOException {
		sendSms(mobiles, content, sp_code, 0);
	}

	public static void sendSms(String mobiles, String content, long task_id) throws IOException {
		sendSms(mobiles, content, sp_code, task_id);
	}

	public static void sendSms(String mobiles, String content, String sp_code) throws IOException {
		sendSms(mobiles, content, sp_code, 0);
	}

	public static void sendSms(String mobiles, String content, String sp_code, long task_id) throws IOException {
		String urlencContent = URLEncoder.encode(content,"utf-8");
        String sign=StringUtils.md5(urlencContent + password);
		String postData = "content=" + urlencContent + "&destMobiles="
				+ mobiles + "&sign=" + sign + "&cust_code=" + cust_code
				+ "&sp_code=" + sp_code + "&task_id=" + task_id;
		System.err.println(postData);
		URL myurl = new URL(smsSvcUrl);
		URLConnection urlc = myurl.openConnection();
		urlc.setReadTimeout(1000 * 30);
		urlc.setDoOutput(true);
		urlc.setDoInput(true);
		urlc.setAllowUserInteraction(false);

		DataOutputStream server = new DataOutputStream(urlc.getOutputStream());

		server.write(postData.getBytes("utf-8"));
		server.close();

		BufferedReader in = new BufferedReader(new InputStreamReader(
				urlc.getInputStream(), "utf-8"));
		String resXml = "", s = "";
		while ((s = in.readLine()) != null)
			resXml = resXml + s + "\r\n";
		in.close();
	}

}

==> util-0.0.2.10-sources.jar: com/crawler/utils/SmsClient.java <==
package com.crawler.utils;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;

import com.crawler.common.config.PropertiesLoader;
import com.crawler.rest.exceptions.extendExceptions.RestSimpleException;

public class SmsClient {
	
	/**
	 * 属性文件加载对象
	 */
	private static PropertiesLoader loader = new PropertiesLoader("sms.properties");
	
	private static final String smsSvcUrl = loader.getProperty("sms.url", "http://43.243.130.33:8860");	   //服务器URL 地址
	private static final String cust_code = loader.getProperty("sms.cust_code", "300270");									 //账号
	private static final String password = loader.getProperty("sms.password", "6C7C6CP7ZM");		 								//密码
	private static final String sp_code = loader.getProperty("sms.sp_code", "10690651549951");                  //接入码（扩展码）
	
	/**
	 * 短信发送
	 * @param phone
	 * @param content
	 */
	public static void send(String phone, String content){
		try {
			SmsClient.sendSms(phone, content);
		} catch (IOException e) {
			throw new RestSimpleException("短信发送失败");
		}
	}

	public static void sendSms(String mobiles, String content) throws IOException {
		sendSms(mobiles, content, sp_code, 0);
	}

	public static void sendSms(String mobiles, String content, long task_id) throws IOException {
		sendSms(mobiles, content, sp_code, task_id);
	}

	public static void sendSms(String mobiles, String content, String sp_code) throws IOException {
		sendSms(mobiles, content, sp_code, 0);
	}

	public static void sendSms(String mobiles, String content, String sp_code, long task_id) throws IOException {
		String urlencContent = URLEncoder.encode(content,"utf-8");
        String sign=StringUtils.md5(urlencContent + password);
		String postData = "content=" + urlencContent + "&destMobiles="
				+ mobiles + "&sign=" + sign + "&cust_code=" + cust_code
				+ "&sp_code=" + sp_code + "&task_id=" + task_id;
		System.err.println(postData);
		URL myurl = new URL(smsSvcUrl);
		URLConnection urlc = myurl.openConnection();
		urlc.setReadTimeout(1000 * 30);
		urlc.setDoOutput(true);
		urlc.setDoInput(true);
		urlc.setAllowUserInteraction(false);

		DataOutputStream server = new DataOutputStream(urlc.getOutputStream());

		server.write(postData.getBytes("utf-8"));
		server.close();

		BufferedReader in = new BufferedReader(new InputStreamReader(
				urlc.getInputStream(), "utf-8"));
		String resXml = "", s = "";
		while ((s = in.readLine()) != null)
			resXml = resXml + s + "\r\n";
		in.close();
	}

}
